﻿using System;
using System.Drawing;

using DevExpress.XtraEditors;
using DevExpress.XtraMap;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Load                                      += Form_Load;
            this.openStreetMapDataProvider.WebRequest += openStreetMapDataProvider_WebRequest;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            #region 맵 항목 저장소를 설정한다.

            MapItemStorage mapItemStorage = new MapItemStorage();

            #endregion
            #region 맵 파이를 설정한다.

            MapPie mapPie = new MapPie();

            mapPie.Size = 200;

            mapPie.Segments.Add(new PieSegment() { Argument = "A", Value = 100 });
            mapPie.Segments.Add(new PieSegment() { Argument = "B", Value = 50  });
            mapPie.Segments.Add(new PieSegment() { Argument = "C", Value = 120 });

            mapItemStorage.Items.Add(mapPie);

            #endregion
            #region 인자 항목 키 공급자를 설정한다.

            ArgumentItemKeyProvider argumentItemKeyProvider = new ArgumentItemKeyProvider();

            #endregion
            #region 키 색상 색상기를 설정한다.

            KeyColorColorizer keyColorColorizer = new KeyColorColorizer();

            keyColorColorizer.Colors.Add(Color.Coral    );
            keyColorColorizer.Colors.Add(Color.Orange   );
            keyColorColorizer.Colors.Add(Color.LightBlue);

            keyColorColorizer.Keys.Add(new ColorizerKeyItem() { Key = "A", Name = "Category A" });
            keyColorColorizer.Keys.Add(new ColorizerKeyItem() { Key = "B", Name = "Category B" });
            keyColorColorizer.Keys.Add(new ColorizerKeyItem() { Key = "C", Name = "Category C" });

            keyColorColorizer.ItemKeyProvider = argumentItemKeyProvider;

            #endregion
            #region 벡터 항목 레이어를 설정한다.

            VectorItemsLayer vectorItemsLayer = new VectorItemsLayer();
            
            vectorItemsLayer.Data      = mapItemStorage;
            vectorItemsLayer.Colorizer = keyColorColorizer;

            this.mapControl.Layers.Add(vectorItemsLayer);

            #endregion
            #region 색상 리스트 레전드를 설정한다.

            ColorListLegend colorListLegend = new ColorListLegend();
            
            colorListLegend.Layer = vectorItemsLayer;

            this.mapControl.Legends.Add(colorListLegend);

            #endregion
        }

        #endregion
        #region OPEN STREET MAP 데이터 공급자 웹 요청시 처리하기 - openStreetMapDataProvider_WebRequest(sender, e)

        /// <summary>
        /// OPEN STREET MAP 데이터 공급자 웹 요청시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void openStreetMapDataProvider_WebRequest(object sender, MapWebRequestEventArgs e)
        {
            e.UserAgent = "XtraMap Getting Started - Connect to OpenStreetMap";
        }

        #endregion
    }
}